#!/usr/bin/env python3
import subprocess
import os

"""
NoNotifications
Copyright (C) 2016  Jacob Vlijm
contact: vlijm@planet.nl
This program is free software: you can redistribute it and/or modify it under
the terms of the GNU General Public License as published by the Free Software
Foundation, either version 3 of the License, or any later version. This
program is distributed in the hope that it will be useful, but WITHOUT ANY
WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR
A PARTICULAR PURPOSE. See the GNU General Public License for more details. You
should have received a copy of the GNU General Public License along with this
program.  If not, see <http://www.gnu.org/licenses/>.
"""

proc = "/opt/nonotifs/nonotifs/nonotifs_monitor"
configdir = os.path.join(os.environ["HOME"], ".config")
prefsdir = os.path.join(configdir, "nonotifs_prefs")
log = os.path.join(prefsdir, "missednotifs")

def get_currentsettings():
    # read the set of preferences
    settings = {}
    for setting in [
        "dimsound", "runonstartup", "storemissed", "specific",
        "showonstart", "spechoice",
        ]:
        settings[setting] = True if read_setting(setting) else False
    return(settings)

def read_specifics():
    # read the set of strings, set in the prefs window (only suppress...)
    specifics_list = os.path.join(prefsdir, "spec_data")
    try:
        return [l for l in open(specifics_list).read().splitlines() \
                if not l == "\n"]
    except FileNotFoundError:
        pass

def read_setting(setting):
    # general function to get current setting; returns either None or True
    stored = os.path.join(prefsdir, setting)
    if os.path.exists(stored):
        return True if open(stored).read().strip() == "True" else False

def mute_sound(sound):
    try:
        subprocess.Popen([
            "amixer", "-q", "-D", "pulse", "sset", "Master", sound
            ])
    except subprocess.CalledProcessError:
        # for possible debug errors
        print("mute sound error")

def check_state():
    # check if the backround process is running
    try: 
        pid = subprocess.check_output(
            ["pgrep", "-f", proc]).decode("utf-8").strip()
        return True
    except subprocess.CalledProcessError:
        return False

def stop_proc():
    # possiby redundant, but it won´t hurt
    mute_sound("on")
    # stop the background process
    try:
        pid = subprocess.check_output(
            ["pgrep", "-f", proc]).decode("utf-8").strip()
        subprocess.call(["pkill", "-P", pid])
    except subprocess.CalledProcessError:
        pass

def start_proc():
    # start the background process
    dim = read_setting("dimsound")
    if dim:
        mute_sound("off")
    try: 
        pid = subprocess.check_output(
            ["pgrep", "-f", proc]).decode("utf-8").strip()
    except subprocess.CalledProcessError:
        subprocess.Popen(proc)

def setup_dirs():
    # make sure the needed dirs exist
    for dr in [configdir, prefsdir]:
        if not os.path.exists(dr):
            os.mkdir(dr)

def remember(last):
    # remember the last state the indicator was running in
    last_run = os.path.join(prefsdir, "last_state")
    open(last_run, "wt").write(last)

def read_lastrun():
    # read back the last saved state
    return read_setting("last_state")

def write_setting(setting, value):
    # helper function to write settings
    file = os.path.join(prefsdir, setting)
    open(file, "wt").write(str(value))
    
