#!/usr/bin/env python3
import gi
gi.require_version('Gtk', '3.0')
from gi.repository import Gtk, Pango, Gdk
import nonotifs_tools
import os

"""
NoNotifications
Copyright (C) 2016  Jacob Vlijm
contact: vlijm@planet.nl
This program is free software: you can redistribute it and/or modify it under
the terms of the GNU General Public License as published by the Free Software
Foundation, either version 3 of the License, or any later version. This
program is distributed in the hope that it will be useful, but WITHOUT ANY
WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR
A PARTICULAR PURPOSE. See the GNU General Public License for more details. You
should have received a copy of the GNU General Public License along with this
program.  If not, see <http://www.gnu.org/licenses/>.
"""

class InterFace(Gtk.Window):

    def __init__(self, wname, text):
        
        Gtk.Window.__init__(self, title=wname)
        # maingrid
        maingrid = Gtk.Grid()
        maingrid.set_column_homogeneous(False)
        maingrid.set_border_width(10)
        self.add(maingrid)
        # distance grid 
        aboutsep2 = Gtk.Grid()
        aboutsep2.set_border_width(5)
        maingrid.attach(aboutsep2, 0, 2, 4, 1)
        # text window
        scrolledwindow = Gtk.ScrolledWindow()
        scrolledwindow.set_hexpand(True)
        scrolledwindow.set_vexpand(True)
        scrolledwindow.set_min_content_height(300)
        maingrid.attach(scrolledwindow, 0, 3, 4, 1)
        # text field
        self.textfield = Gtk.TextView()
        self.textbuffer = self.textfield.get_buffer()
        self.textbuffer.set_text(text)
        self.textfield.set_wrap_mode(Gtk.WrapMode.WORD)
        self.textfield.set_editable(False)
        self.textfield.modify_font(Pango.FontDescription('Ubuntu Mono 12'))
        self.textfield.modify_fg(Gtk.StateFlags.NORMAL, Gdk.color_parse("black"))
        scrolledwindow.add(self.textfield)
        # separator
        bottomsep = Gtk.Grid()
        maingrid.attach(bottomsep, 0, 4, 4, 1)
        bottomsep.set_border_width(5)
        # grid
        bottombutton_grid = Gtk.Grid()
        bottombutton_grid.set_column_spacing(\
            250) if wname == "Recently missed notifications" else\
            bottombutton_grid.set_column_spacing(350)                     
        maingrid.attach(bottombutton_grid, 0, 5, 4, 1)
        # placeholder, to be able to use set_column_spacing()
        fakebutton = Gtk.Grid()
        fakebutton.set_border_width(5)
        bottombutton_grid.attach(fakebutton, 0, 0, 1, 1)
        if wname == "Recently missed notifications":
            # clearbutton
            clearbutton = Gtk.Button("_Clear", use_underline=True)
            clearbutton.set_label("Clear log")
            clearbutton.connect("clicked", self.clear_log)
            bottombutton_grid.attach(clearbutton, 0, 1, 1, 1)
        # quitbutton
        quitbutton = Gtk.Button("_Close", use_underline=True)
        quitbutton.set_label("Close")
        quitbutton.connect("clicked", self.on_close_clicked)
        #quitbutton.set_size_request(120,20)
        bottombutton_grid.attach(quitbutton, 3, 1, 1, 1)

    def clear_log(self, button):
        try:
            os.remove(nonotifs_tools.log)
        except FileNotFoundError:
            pass
        self.textbuffer.set_text("")
        
    def on_close_clicked(self, button):
        Gtk.main_quit()

def run_gui(window_title, read_text):
    window = InterFace(window_title, read_text)
    window.connect("delete-event", Gtk.main_quit)
    window.set_resizable(False)
    window.set_wmclass("NoNotifications", "nonotifs")
    window.show_all()
    Gtk.main()

if __name__ == "__main__":
    read_text = read_text()
    run_gui("About & legal notice", read_text )
